{% extends "layout.html" %}

{% block title %}Login{% endblock title %}

{% block body %}

<h2>Login</h2>

<form action="{{ url_for('login') }}" method=POST>

<dl>
<dt>Username
    <dd><input type=text name=username>

<dt>Password
    <dd><input type=password name=password>
</dl>

<p><input type=submit value=Login>

</form>

{% endblock body %}
